summaryrefslogtreecommitdiff
path: root/src/helper.h
diff options
context:
space:
mode:
authorTannin <sherb@gmx.net>2016-05-15 14:58:54 +0200
committerTannin <sherb@gmx.net>2016-05-15 14:58:54 +0200
commit5665be7fd126c435ed4ad4ceb8c01f0e6eb16975 (patch)
tree1a9d9bdbb20d492a1b434e916b4be87cafd5a415 /src/helper.h
parente522afa63b81301caf886c5e351de2790e5b8182 (diff)
fixed calls to helper.exe using wrong path
Diffstat (limited to 'src/helper.h')
-rw-r--r--src/helper.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/helper.h b/src/helper.h
index 410e2527..cd4b7883 100644
--- a/src/helper.h
+++ b/src/helper.h
@@ -38,17 +38,17 @@ namespace Helper {
* This will create all required sub-directories and give the user running ModOrganizer
* write-access
*
* @param moDirectory absolute path to the ModOrganizer base directory
* @return true on success
**/
-bool init(const std::wstring &moDirectory);
+bool init(const std::wstring &moPath, const std::wstring &dataPath);
/**
* @brief sets the last modified time for all .bsa-files in the target directory well into the past
* @param moDirectory absolute path to the modOrganizer base directory
* @param dataPath the path taht contains the .bsa-files, usually the data directory of the game
**/
-bool backdateBSAs(const std::wstring &moDirectory, const std::wstring &dataPath);
+bool backdateBSAs(const std::wstring &moPath, const std::wstring &dataPath);
}
@@ -38,17 +38,17 @@ namespace Helper {
* write-access
*
- * @param moDirectory absolute path to the ModOrganizer base directory
+ * @param moPath absolute path to the ModOrganizer base directory
* @return true on success
**/
@@ -38,17 +38,17 @@ namespace Helper {
/**
* @brief sets the last modified time for all .bsa-files in the target directory well into the past
- * @param moDirectory absolute path to the modOrganizer base directory
+ * @param moPath absolute path to the modOrganizer base directory
* @param dataPath the path taht contains the .bsa-files, usually the data directory of the game
**/